@@ -6,12 +6,12 @@ use IO::Socket::Multicast;
 
 use constant DESTINATION => '226.1.1.2:2000';
 
-my $sock = IO::Socket::INET->new(Proto=>'udp',PeerAddr=>DESTINATION);
+my $sock = IO::Socket::Multicast->new;
 
 while (1) {
   my $message = localtime;
   $message .= "\n" . `who`;
-  $sock->send($message) || die "Couldn't send: $!";
+  $sock->mcast_send($message,DESTINATION) || die "Couldn't send: $!";
 } continue {
-  sleep 10;
+  sleep 5;
 }
